dataf.geneexp <- function() return(structure(list(
  name = "Gene expression profile",
  args = "Time",
  vals = "Gene Expression Level",
  dataf = list(structure(list(args = c(1, 2, 3, 
4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 
37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
53, 54, 55, 56, 57, 58), vals = c(-0.79346, -0.72282, -1.1507, 
-1.2593, -1.1293, -1.7204, -1.8905, -1.8289, -1.2071, -1.13, 
-1.4441, -1.406, -1.1594, -1.1599, -1.2878, -0.85163, -0.92525, 
-0.78914, -1.3369, -1.5664, -1.2087, -1.6093, -1.7531, -1.758, 
-1.6204, -1.8012, -1.9443, -2.1064, -2.1235, -2.0531, -1.8445, 
-2.1241, -1.9314, -1.9622, -1.713, -1.7509, -1.6296, -1.3865, 
-1.7515, -1.3763, -0.94793, -1.2154, -1.3163, -1.4855, -1.7739, 
-1.1058, -1.9344, -1.5353, -1.0951, -1.7092, -1.4659, -1.2541, 
-1.5393, -1.5075, -1.3383, -1.5323, -0.76116, -0.020631)), .Names = c("args", 
"vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 
10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 
42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 
58), vals = c(-2.9237, -2.3027, -2.5953, -2.6431, -2.9831, -1.9908, 
-1.6091, -1.9276, -1.7989, -1.979, -1.7403, -1.7994, -2.4304, 
-1.7085, -3.0015, -2.2597, -2.5687, -2.9699, -2.6344, -2.4365, 
-2.1965, -2.7078, -2.4194, -2.2789, -2.5334, -2.868, -2.7163, 
-2.2781, -2.2212, -1.7868, -1.3285, -2.3139, -2.1579, -1.3323, 
-1.1929, -1.3453, -0.81118, -0.61914, -0.5528, -1.433, -3.2909, 
-2.4675, -2.3171, -2.3398, -1.9107, -2.4868, -1.9697, -1.9728, 
-2.222, -1.2862, -2.2955, -1.826, -1.412, -1.9418, -0.91909, 
1.2252, 1.7191, 2.5376)), .Names = c("args", "vals")), structure(list(
    args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
    16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 
    31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 
    46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(0.012875, 
    0.54291, 0.39255, 1.0531, 1.8504, 2.6788, 3.258, 3.2666, 
    2.8947, 2.5465, 2.5699, 1.7148, 1.4883, 1.1486, 0.95165, 
    0.60407, 1.0956, -0.39961, -1.4592, -0.97673, -1.0708, -1.4571, 
    -1.5132, -1.5329, -2.1501, -1.9411, -2.0356, -2.1392, -2.2907, 
    -2.1826, -2.1945, -1.9167, -2.3744, -2.1768, -2.6607, -2.0388, 
    -1.8542, -2.0915, -1.7683, -1.3575, -1.8819, -2.0613, -1.8365, 
    -1.8292, -1.9567, -1.6103, -1.8209, -1.11, -1.4996, -0.98583, 
    -1.4011, -1.4696, -1.2322, -1.1479, -2.2176, -2.191, -2.4955, 
    -2.8947)), .Names = c("args", "vals")), structure(list(args = c(1, 
2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 
20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
52, 53, 54, 55, 56, 57, 58), vals = c(0.6648, 0.71952, 0.69399, 
1.0951, 1.351, 2.0205, 2.0547, 2.1753, 2.3976, 2.1094, 2.0807, 
1.742, 1.625, 1.4568, 1.0819, 1.6432, 1.1584, 1.2409, 0.3143, 
0.58087, 0.58163, 0.39639, 0.094816, -0.1501, -0.29, -0.20552, 
-0.78168, -0.65061, -0.36965, -0.6619, -1.1946, -1.1276, -1.1635, 
-1.3549, -1.1001, -1.2154, -1.3714, -1.6283, -1.4729, -0.67314, 
-0.33132, -0.39986, -0.33167, -0.83143, -0.89797, -0.75742, -0.55735, 
-0.41359, -0.38334, -0.82859, -0.25305, -0.88527, -0.7697, -0.49219, 
-1.5014, -1.7083, -1.9584, -1.5321)), .Names = c("args", "vals"
)), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 
28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 
44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58), 
    vals = c(-1.7925, -1.9611, -1.976, -1.9186, -1.9686, -2.2917, 
    -1.9044, -1.6386, -2.0419, -1.6748, -2.1899, -1.1541, -2.0625, 
    -2.2392, -1.9201, -1.7523, -1.8647, -2.2165, -1.8356, -1.7325, 
    -1.5851, -1.6729, -1.3059, -1.3808, -1.2628, -1.7965, -1.7009, 
    -1.5518, -1.6073, -1.2234, -0.91518, -0.76311, -1.1418, -1.381, 
    -0.91266, -1.1619, -1.2233, -1.1135, -0.85427, -1.2815, -1.3147, 
    -1.0157, -1.4202, -1.2221, -1.1709, -2.1365, -2.0055, -1.93, 
    -1.8437, -1.5225, -1.9601, -0.4449, -0.94623, -0.65994, 0.57873, 
    1.2035, 1.6094, 1.5759)), .Names = c("args", "vals")), structure(list(
    args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
    16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 
    31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 
    46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(1.0482, 
    1.3086, 1.6183, 1.6691, 2.0618, 2.4132, 2.3888, 2.3113, 2.5517, 
    2.5471, 2.629, 2.0421, 1.8806, 1.4594, 1.5782, 1.4648, 1.3702, 
    0.93122, 0.26492, 0.58102, 0.1621, -0.089822, -0.34356, -0.55483, 
    -0.82152, -0.94071, -1.5533, -1.5751, -1.3185, -1.733, -1.57, 
    -1.4701, -1.1053, -1.4502, -0.59434, -0.7028, -0.52149, -1.155, 
    -1.1425, -0.70915, -1.1731, -0.7073, -0.85389, -1.2348, -1.0732, 
    -0.64193, -0.94265, -0.32552, -0.48599, -0.49183, -1.0672, 
    -0.92053, -1.1667, -1.3988, -1.5481, -1.9106, -2.0763, -2.2972
    )), .Names = c("args", "vals")), structure(list(args = c(1, 
2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 
20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
52, 53, 54, 55, 56, 57, 58), vals = c(0.79292, 0.9523, 1.3392, 
1.4554, 1.8893, 2.2347, 2.2338, 2.1101, 2.1066, 1.9989, 2.0791, 
1.5794, 1.3979, 1.0516, 1.2115, 0.97424, 1.0062, 0.20274, -0.20633, 
-0.20398, -0.46979, -0.93601, -0.74061, -0.67741, -0.95927, -1.047, 
-1.372, -1.6804, -1.5373, -1.6602, -1.1499, -1.5344, -1.7358, 
-1.2336, -0.93484, -1.103, -1.0708, -1.1203, -0.61519, -1.3955, 
-0.49976, -0.7862, -0.57059, -0.90059, -0.56299, -1.1129, -0.64078, 
-0.48783, -0.62334, -0.26929, -0.50791, -0.73632, -0.50362, -1.0207, 
-1.7806, -1.4889, -1.7085, -1.6877)), .Names = c("args", "vals"
)), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 
28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 
44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58), 
    vals = c(0.84809, 1.376, 2.1127, 1.9301, 2.6181, 2.6503, 
    2.2885, 1.8839, 0.92443, 0.92023, 1.1347, 1.1064, 0.96041, 
    1.2286, 0.88536, 0.92572, 0.80553, -0.076896, -0.31587, -0.25326, 
    -0.46411, -0.65685, -0.92195, -0.64383, -1.0379, -1.216, 
    -1.3579, -1.2745, -1.3508, -1.4414, -1.031, -1.5037, -1.7109, 
    -1.1026, -1.2745, -1.3144, -1.7634, -1.5522, -1.004, -1.1416, 
    -0.89195, -1.0741, -1.1459, -0.89495, -1.1294, -0.67528, 
    -0.72801, -0.53878, -0.1955, -0.3293, -0.55041, -0.9832, 
    -0.55637, -0.81295, -1.7716, -1.5527, -1.8052, -2.1866)), .Names = c("args", 
"vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 
10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 
42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 
58), vals = c(-2.4971, -2.5373, -2.4136, -2.2974, -2.2307, -2.1471, 
-1.8089, -1.7506, -1.6594, -1.5625, -1.5174, -1.7709, -1.6885, 
-2.0027, -2.1217, -1.7514, -1.8223, -1.7503, -1.1565, -1.4987, 
-1.4364, -1.5246, -1.1547, -0.85294, -0.97046, -0.4414, -0.27693, 
-0.29009, -0.58615, -0.53882, -0.65488, -0.35291, -0.64562, -0.70815, 
-0.68461, -1.0094, -1.0507, -1.071, -0.84101, -1.0441, -0.85233, 
-1.2883, -1.3098, -1.3918, -0.62437, -1.2385, -1.7198, -0.84072, 
-1.1826, -0.90406, -0.99757, -0.92359, -0.88185, -0.76023, -0.36434, 
-0.029165, 0.66863, 0.66612)), .Names = c("args", "vals")), structure(list(
    args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
    16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 
    31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 
    46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-2.935, 
    -2.8941, -2.595, -2.9575, -2.7484, -2.6137, -2.4772, -2.2623, 
    -2.5435, -2.301, -2.513, -1.4675, -2.4154, -2.374, -1.6868, 
    -2.2708, -2.1148, -2.0927, -2.3797, -2.2327, -1.9034, -2.0437, 
    -1.9306, -1.309, -1.7931, -1.8825, -1.3705, -1.288, -1.8199, 
    -1.627, -2.1355, -2.1393, -2.6322, -1.9628, -2.3385, -2.0218, 
    -2.2874, -2.0252, -1.8153, -2.3615, -3.1811, -2.5212, -2.5742, 
    -2.3961, -2.9316, -2.8931, -2.3292, -2.4506, -2.6527, -2.3129, 
    -2.6529, -2.3822, -2.1897, -2.8689, -2.0812, 0.32188, 1.3789, 
    1.8227)), .Names = c("args", "vals")), structure(list(args = c(1, 
2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 
20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
52, 53, 54, 55, 56, 57, 58), vals = c(-2.2204, -2.1197, -2.0283, 
-1.7947, -1.1938, -1.2809, -1.6594, -1.86, -1.9558, -2.0185, 
-2.2633, -2.0099, -2.1414, -2.0686, -1.6393, -1.4278, -1.5052, 
-1.2922, -1.1492, -1.1816, -1.3116, -1.4018, -1.133, -1.1776, 
-0.92822, -0.83618, -0.33538, -0.55901, -0.47966, -0.53473, -1.1856, 
-1.8321, -1.8238, -1.3965, -1.2294, -1.5218, -0.51136, -1.1256, 
-0.99192, -1.402, -0.62486, -0.38479, -0.7805, -0.80139, -0.66597, 
-0.3756, -1.0019, -0.47293, -0.67972, -0.47457, -0.65573, -0.26031, 
-0.3687, -0.56012, 0.75234, 0.54986, 1.0801, 1.0315)), .Names = c("args", 
"vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 
10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 
42, 43, 44, 45, 46, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58
), vals = c(-2.2727, -2.6149, -2.0871, -2.1624, -1.8717, -1.8731, 
-1.6399, -1.5838, -1.2569, -1.2291, -1.105, -1.3092, -1.1471, 
-1.4367, -2.0917, -1.1912, -1.2659, -2.0436, -1.7859, -1.7299, 
-1.8774, -2.3822, -2.2119, -1.8291, -2.0212, -1.6686, -1.7595, 
-1.7209, -1.7115, -1.5953, -1.7217, -1.4696, -1.4471, -1.0806, 
-1.5074, -1.2352, -1.3727, -1.1228, -1.2331, -1.1951, -0.29478, 
-1.3315, -1.5556, -1.0823, -0.87551, -1.3008, -0.19811, -0.45936, 
-0.27704, -0.34483, -1.0286, 0.4811, 0.72541, 1.9851, 2.2727, 
2.4818, 2.0396)), .Names = c("args", "vals")), structure(list(
    args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
    16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 
    31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 
    46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-2.7475, 
    -2.5094, -2.427, -2.0922, -2.0596, -1.7612, -1.7399, -1.7083, 
    -1.3598, -1.2163, -1.4821, -1.9341, -1.6585, -1.788, -1.7361, 
    -1.4663, -1.5466, -1.3588, -1.4329, -1.4414, -1.5503, -1.8134, 
    -1.6691, -1.7187, -1.9935, -1.792, -1.4476, -1.4945, -1.9585, 
    -1.5737, -1.5261, -1.5481, -1.5125, -1.6459, -2.3148, -1.6525, 
    -2.5251, -2.5696, -2.1973, -1.3856, -1.7097, -1.4321, -1.2026, 
    -1.5029, -1.0703, -1.4015, -1.3826, -1.3404, -1.4686, -1.4942, 
    -1.2091, -0.93255, -1.3839, -1.5552, -1.3285, -0.068597, 
    0.63569, 0.78854)), .Names = c("args", "vals")), structure(list(
    args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
    16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 
    31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 
    46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-0.72444, 
    -0.76817, -1.004, -0.8603, -0.78179, -0.41719, -0.53807, 
    -0.53256, -0.67077, -1.1659, -1.1104, -1.1296, -1.2649, -1.1946, 
    -1.1507, -0.75183, -0.72139, -0.47571, -0.48232, -0.36371, 
    -0.16425, 0.15927, 0.32528, -0.044916, 0.63644, 0.35244, 
    0.34664, 0.63471, 0.31018, 0.41415, 0.13964, 0.11521, 0.50556, 
    -0.17909, 0.54732, -0.34159, 0.54648, 0.25057, -0.56087, 
    -1.5746, -0.37623, -1.3944, -1.4232, -1.7043, -1.586, -1.2329, 
    -2.2449, -1.5766, -1.3626, -1.9903, -1.7058, -1.0173, -1.3015, 
    -0.76902, 0.3175, 0.74246, 0.87454, 1.1087)), .Names = c("args", 
"vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 
10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 
42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 
58), vals = c(-1.9098, -2.2504, -2.3542, -1.7173, -1.7936, -1.925, 
-1.935, -1.8081, -2.1531, -1.4244, -1.848, -1.1934, -1.1576, 
-2.0252, -2.3111, -1.9399, -1.9278, -2.3593, -2.3845, -2.3021, 
-1.9214, -2.2228, -1.9805, -2.235, -2.041, -2.2422, -1.6459, 
-1.9747, -2.1425, -2.3564, -1.0808, -1.5839, -1.0907, -1.8253, 
-1.0533, -1.059, -1.3892, -0.93776, -0.8534, -1.434, -1.2886, 
-1.2159, -1.3142, -0.68278, -0.047018, -0.47469, -1.3302, 1.0768, 
0.59085, -0.84664, -1.1913, -1.0452, -1.5946, -1.5418, -1.2384, 
-1.0844, -0.98738, -1.1304)), .Names = c("args", "vals")), structure(list(
    args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
    16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 
    31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 
    46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-3.778, 
    -3.7013, -3.4236, -3.8591, -4.2063, -4.177, -4.1718, -4.2285, 
    -4.428, -4.0572, -4.1206, -3.5574, -4.2401, -4.12, -3.6542, 
    -3.2404, -3.3338, -3.7621, -3.5018, -3.1215, -2.4137, -2.9459, 
    -2.9292, -2.2957, -2.3441, -3.0366, -2.4036, -2.335, -2.5374, 
    -1.9795, -2.1784, -2.461, -2.5887, -2.3384, -2.1609, -2.1472, 
    -1.7959, -1.1212, -1.6657, -3.1536, -2.9683, -4.4004, -4.2828, 
    -4.8756, -4.5265, -4.3486, -3.9635, -4.9043, -4.0765, -3.6007, 
    -4.404, -3.9554, -3.1806, -3.6648, -3.014, 1.7581, 2.3147, 
    3.1392)), .Names = c("args", "vals")), structure(list(args = c(1, 
2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 
20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
52, 53, 54, 55, 56, 57, 58), vals = c(-2.2106, -2.3216, -2.6404, 
-2.0838, -2.368, -2.4199, -1.9293, -2.1786, -2.0776, -1.9324, 
-2.4206, -2.0579, -2.4495, -2.2969, -2.9193, -1.3253, -2.2407, 
-1.8839, -1.8358, -2.2464, -1.952, -2.048, -1.7441, -1.308, -1.9929, 
-2.0884, -1.9483, -1.7738, -1.7972, -1.2237, -1.4877, -1.2919, 
-1.5378, -0.95394, -1.4501, -0.81707, -1.2893, -0.96707, -0.20339, 
-1.6816, -0.51592, -2.4516, -2.0551, -1.5648, -1.4546, -1.7113, 
-1.1216, -1.9126, -1.5625, -1.7861, -2.0267, -1.2595, -1.7043, 
-1.2201, -1.2529, 0.5353, 0.87361, 0.60546)), .Names = c("args", 
"vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 
10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 
42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 
58), vals = c(-0.38784, -0.71272, -0.58395, -0.58439, -0.45742, 
-1.0198, -1.4433, -1.5137, -1.4051, -1.0695, -1.1391, -1.6012, 
-0.86499, -1.2874, -1.066, -0.60874, -0.59527, -0.12706, -0.55067, 
-0.46257, -0.31258, -0.52803, -0.54244, -0.67885, -0.76104, -1.0072, 
-1.6537, -1.8046, -1.3995, -1.5469, -2.078, -1.8745, -1.673, 
-2.0578, -1.5238, -1.5538, -1.2933, -1.7632, -1.6508, -1.5172, 
-0.64418, -1.155, -0.99452, -1.0034, -1.0511, -1.0011, -0.97482, 
-1.0189, -0.8697, -0.66891, -1.0655, -0.10921, -0.42596, -0.52896, 
0.17541, -0.50596, -0.48372, -0.62951)), .Names = c("args", "vals"
)), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 
28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 
44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58), 
    vals = c(-0.54359, -0.65546, -0.74479, -0.61564, -0.86965, 
    -1.2706, -1.2448, -1.1392, -1.3068, -0.9382, -1.4724, -0.84077, 
    -1.2435, -1.1408, -1.284, -1.0574, -1.2419, -1.1373, -1.0329, 
    -0.99262, -0.70482, -0.82487, -0.55322, -0.52084, -1.2845, 
    -1.0749, -1.0902, -1.1671, -0.75964, -0.87079, -0.52594, 
    -0.017274, -1.9159, -0.18597, -0.61599, -0.70537, -0.60526, 
    -0.66251, -0.32633, -1.3035, -0.92662, -1.6479, -1.2818, 
    -0.7126, -0.92059, -1.8693, -1.3506, -1.0264, -0.99432, -0.59921, 
    -1.2595, -0.24357, -0.43002, 0.083507, -0.033828, 0.46972, 
    0.21572, 0.97072)), .Names = c("args", "vals")), structure(list(
    args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
    16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 
    31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 
    46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(0.97492, 
    1.0717, 1.2324, 1.2593, 1.685, 2.0139, 2.2429, 2.2013, 2.2248, 
    2.0139, 2.4604, 1.5907, 1.3883, 1.1179, 1.0831, 0.96327, 
    1.0842, 0.4454, -0.024521, 0.38816, 0.15865, -0.21118, -0.48191, 
    -0.46717, -0.47723, -0.40083, -0.55778, -0.74242, -0.37738, 
    -0.63417, -0.48312, -0.65404, -0.79972, -0.57369, -1.3658, 
    -1.0051, -1.5472, -1.461, -1.4412, -0.87002, -1.143, -0.9128, 
    -0.66796, -0.83015, -1.0066, -0.93714, -1.127, -0.72119, 
    -0.76209, -0.69445, -0.62477, -0.68916, -0.63353, -1.2612, 
    -1.6555, -1.7668, -1.9891, -1.6532)), .Names = c("args", 
"vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 
10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 
42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 
58), vals = c(-1.8578, -1.8985, -2.1196, -1.7855, -2.0354, -1.9596, 
-1.0689, -1.4064, -1.4869, -1.5505, -1.8055, -1.7008, -2.0745, 
-1.83, -1.9553, -1.6857, -1.9451, -2.0127, -1.868, -1.5625, -1.9624, 
-1.9119, -1.9749, -1.6513, -1.6689, -1.7814, -1.8707, -1.6933, 
-1.5086, -1.5261, -0.16813, -0.73535, -0.9151, -0.40462, -0.48592, 
-0.39817, -1.0161, -0.24353, 0.10998, -0.78803, -0.52916, -1.0944, 
-0.90698, -0.36188, -0.64918, -1.019, -1.2155, -0.96465, -0.85491, 
-0.78928, -0.81293, -0.64781, -0.78736, -0.48355, 0.39936, 2.5213, 
1.2019, -0.070349)), .Names = c("args", "vals")), structure(list(
    args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
    16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 
    31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 
    46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(0.86305, 
    0.73865, 1.0447, 1.2953, 2.0084, 2.0611, 2.4025, 2.2306, 
    2.5086, 2.5674, 2.5404, 2.4038, 2.5399, 2.3899, 2.7886, 2.5011, 
    3.0747, 1.3217, 0.092391, 0.19143, 0.16806, -0.58406, -0.57016, 
    -0.56912, -1.2479, -0.89981, -1.0149, -1.0868, -0.71627, 
    -0.88356, -0.76246, -1.1053, -1.6964, -1.0147, -1.4891, -0.85, 
    -0.49243, -0.65674, -0.26814, -0.26076, -0.26291, -1.0745, 
    -1.047, -0.69626, -0.4487, -0.44785, -0.084818, 0.48961, 
    0.48843, 0.8026, 1.0675, -1.6418, -0.35512, -0.57959, -1.7847, 
    -1.4698, -1.5665, -2.2529)), .Names = c("args", "vals")), 
    structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
    12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 
    27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 
    42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
    57, 58), vals = c(0.35404, 0.20618, 0.45756, 0.8705, 1.0183, 
    1.4905, 1.5019, 1.6652, 1.6308, 1.5357, 1.6721, 1.1555, 0.95899, 
    1.4377, 1.0575, 1.1023, 1.0022, 0.64513, 0.32201, 0.16842, 
    0.034455, -0.090135, -0.4606, -0.6877, -0.71392, -0.65058, 
    -0.66523, -0.54618, -0.82859, -0.86747, -1.1282, -1.7028, 
    -0.99836, -1.2961, -0.56379, -0.99903, -0.92851, -1.3723, 
    -1.4075, -1.2459, -0.344, -0.98982, -1.0033, -1.2384, -1.1863, 
    -1.175, -1.6308, -1.5412, -1.0187, -1.07, -1.2885, -0.80448, 
    -1.2782, -1.06, -0.99544, -1.1429, -1.0468, -1.5905)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 33, 34, 36, 37, 38, 39, 40, 
    41, 43, 44, 45, 46, 47, 48, 49, 50, 51, 53, 54, 55, 56, 57, 
    58), vals = c(-1.8451, -2.0949, -2.2672, -2.3024, -1.708, 
    -1.6447, -1.8971, -2.0226, -2.0946, -1.5226, -1.8791, -1.7306, 
    -1.4611, -1.8045, -1.4203, -1.6994, -1.5835, -1.5248, -1.8595, 
    -1.7914, -1.5399, -1.6443, -1.2062, -1.2156, -1.1959, -1.0254, 
    -1.0114, -1.1722, -1.3578, -0.97305, -0.67548, -0.47264, 
    -0.29619, -0.4131, -0.74616, -0.8259, -1.3027, -1.2955, -1.5403, 
    -1.5539, -1.6726, -1.9712, -1.2532, -2.3553, -1.6145, -1.8022, 
    -1.9177, -2.2349, -1.8872, -2.1151, -1.6481, -1.0895, -0.11998, 
    0.82429)), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(1.0031, 
    0.89532, 0.18505, 2.6189, 4.174, 4.8863, 3.6903, 2.5679, 
    -0.5557, -1.3196, -0.91746, -1.4929, -3.0427, -2.378, -1.7144, 
    -1.8245, -2.2278, -3.3753, -3.026, -1.982, -2.4781, -2.6698, 
    -3.1143, -2.7738, -2.6823, -3.3244, -3.3223, -3.4011, -3.223, 
    -2.8073, -2.6632, -2.5265, -3.0611, -2.5951, -2.7975, -2.1079, 
    -2.3848, -1.8038, -1.6098, -2.2318, -0.7009, -2.8811, -2.5688, 
    -3.0257, -2.6368, -2.5873, -2.6786, -3.1108, -2.387, -2.0863, 
    -3.1362, -2.7512, -2.326, -2.3103, -2.4037, -2.8056, -2.865, 
    -3.0461)), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-1.7452, 
    -1.621, -1.85, -1.8237, -1.9213, -1.7725, -2.039, -2.2283, 
    -2.1167, -2.0428, -2.4272, -1.881, -2.1481, -2.0699, -1.8183, 
    -2.1091, -2.4895, -2.4064, -1.8772, -2.0244, -2.001, -2.0067, 
    -2.7635, -2.2521, -2.5578, -2.676, -2.5018, -2.4063, -2.9202, 
    -2.4185, -1.2527, -1.4148, -1.9804, -1.5345, -1.6964, -1.4762, 
    -1.3606, -0.64196, -1.4378, -2.0101, -2.5716, -2.6758, -2.0284, 
    -2.2688, -2.2123, -2.8862, -2.6285, -2.6445, -1.966, -1.872, 
    -2.6848, -2.0878, -2.0086, -1.9586, -2.3817, -1.919, -2.0213, 
    -0.23672)), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(1.0269, 
    1.1906, 1.7092, 1.6832, 2.0055, 2.3466, 2.3787, 2.4351, 2.2659, 
    2.2475, 2.3215, 1.7972, 1.7221, 1.6965, 1.1247, 0.89712, 
    1.3231, 0.63019, -0.3615, 0.20156, 0.013578, -0.25303, -0.55243, 
    -0.48872, -0.50075, -0.42621, -1.2565, -1.2993, -1.0358, 
    -1.3995, -1.5251, -1.7372, -1.2306, -1.5274, -1.0723, -1.6023, 
    -1.9799, -1.8196, -1.1328, -1.3123, -1.8708, -0.78702, -0.97184, 
    -1.1106, -1.5558, -1.0278, -1.543, -1.0516, -0.41008, -0.95468, 
    -1.1978, -0.75432, -1.1044, -1.2133, -1.4844, -1.4492, -1.9265, 
    -1.7604)), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-3.2018, 
    -3.3843, -2.2362, -2.4237, -3.694, -2.9812, -2.5195, -2.6642, 
    -2.8177, -2.6846, -2.8251, -2.1831, -2.7414, -2.1354, -2.9456, 
    -2.0017, -2.4889, -3.1887, -2.793, -1.9506, -2.4753, -3.1781, 
    -3.3725, -3.0194, -2.5735, -3.4571, -3.0161, -3.0851, -2.1181, 
    -3.3768, -1.28, -2.3247, -1.9758, -1.839, -2.0688, -1.7895, 
    -1.6746, -1.0105, -1.6089, -1.9377, -2.4127, -3.63, -3.2126, 
    -3.2969, -2.5532, -3.8899, -2.3105, -2.9655, -2.5128, -2.7894, 
    -3.0372, -3.0159, -1.6996, -1.5095, -2.5096, -2.8045, -2.1336, 
    -2.4208)), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(0.19607, 
    0.48623, 0.32146, 0.43916, 0.59019, 1.5428, 1.8111, 1.4385, 
    1.8449, 1.5088, 1.8077, 1.4713, 1.5026, 1.7863, 1.3992, 0.61646, 
    1.3488, 0.47486, 0.025249, -0.15009, -0.35413, -0.3152, -0.81424, 
    -0.77863, -0.70491, -1.1233, -1.2515, -1.2304, -1.047, -1.0364, 
    -0.98892, -1.6361, -1.9184, -1.0295, -1.4788, -1.3412, -1.4026, 
    -1.582, -1.1393, -1.539, 0.62259, -1.1183, -1.3686, -1.2846, 
    -1.2138, -0.79284, -1.458, -0.5518, -0.68496, -0.92185, -0.80494, 
    -0.79504, -0.5305, -0.91446, -1.055, -1.5522, -1.8499, -1.8077
    )), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 34, 
    35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 
    50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-0.83347, -0.60602, 
    -0.50768, -0.12228, -0.089261, 0.13937, -0.28999, -0.63059, 
    -0.80241, -1.0125, -1.1906, -0.70604, -0.76433, -0.47512, 
    -0.46089, -0.89103, -0.95839, -0.85265, -0.53415, -0.73143, 
    -0.53766, -0.55648, -0.84211, -0.76137, -0.74501, -0.84287, 
    -1.7811, -1.4792, -1.3465, -1.1287, -1.2442, -1.0138, -1.0155, 
    -0.83597, -1.0295, -1.3312, -1.2932, -1.4636, -0.91007, -0.7217, 
    -0.91422, -0.43768, -0.45618, -1.3501, -1.0353, -0.69839, 
    -0.912, -0.86292, -1.0496, -0.80288, -0.42316, -0.89189, 
    -1.2367, -0.59829, -0.82854, -0.17422, -0.13364)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(-1.8305, -1.3747, -1.2648, 
    -1.0548, -0.80461, -0.62518, -0.79874, -0.9037, -0.61828, 
    -1.2379, -1.3482, -1.1932, -1.2876, -1.2727, -1.985, -2.0099, 
    -2.0247, -1.6439, -1.4805, -1.7065, -1.5958, -1.2129, -1.6271, 
    -1.8869, -1.5425, -1.6397, -1.8794, -1.7913, -1.5403, -1.7086, 
    -0.99957, -1.1678, -1.3357, -1.1386, -1.2081, -1.0198, -1.8859, 
    -1.4049, -1.8191, -1.5514, 0.023271, -1.4723, -1.371, -1.814, 
    -2.1164, -1.563, -1.5777, -1.9931, -1.6801, -2.0626, -1.7401, 
    -1.382, -1.7373, -1.6044, -1.8285, -1.5251, -0.60472, 0.64566
    )), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-2.7715, 
    -2.9358, -2.059, -2.4567, -2.178, -2.2988, -2.1034, -2.3327, 
    -2.314, -2.157, -2.098, -2.2676, -2.2741, -2.1313, -2.8338, 
    -2.2703, -2.039, -2.1486, -1.8943, -1.834, -1.8851, -2.0213, 
    -0.61385, 0.069984, 0.070269, 0.90947, 1.5968, 1.5699, 1.2938, 
    1.6316, 0.16238, 0.22566, -0.12398, 0.41864, 0.11115, 0.27903, 
    0.8615, 0.1493, 1.2974, -1.2458, -1.404, -3.612, -2.7087, 
    -2.2865, -1.1036, -0.98605, -0.54312, -2.4153, -2.5295, -1.8163, 
    -2.2852, -0.57137, -0.63458, 0.4624, 1.6921, 2.4776, 2.8338, 
    3.1303)), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(0.098804, 
    0.56716, 1.0031, 1.3854, 1.7936, 2.5883, 2.3739, 1.892, 0.99601, 
    0.44224, 0.94348, 0.37037, -0.021034, 0.053731, 0.21842, 
    0.02306, 0.066196, -0.63761, -0.35125, -0.26844, -0.58678, 
    -0.65438, -0.71807, -0.62297, -1.2239, -0.75573, -1.0756, 
    -1.0586, -0.76954, -0.95455, -1.7038, -1.843, -1.8669, -1.6253, 
    -1.9312, -1.5826, -1.7684, -1.892, -1.2066, -1.2372, -1.2117, 
    -1.1063, -1.087, -1.1207, -1.3447, -1.3718, -0.35295, -0.79913, 
    -0.83841, -1.0848, -0.35242, -0.97423, -0.4607, -0.87531, 
    -1.4323, -1.493, -1.4178, -1.2133)), .Names = c("args", "vals"
    )), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
    11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
    26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 
    41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 
    56, 57, 58), vals = c(-2.5466, -2.3681, -2.6224, -3.0472, 
    -3.8854, -4.2686, -3.8078, -3.2147, -3.0718, -2.7762, -2.7236, 
    -2.5308, -3.2928, -2.7877, -3.3594, -3.4924, -2.9802, -2.7203, 
    -2.6798, -2.1874, -2.0187, -2.0023, -2.0047, -2.1081, -2.5776, 
    -2.3074, -2.3492, -2.2424, -2.3186, -1.9346, -1.1333, -0.88048, 
    -0.9283, -0.4244, -1.9794, -0.54051, -1.1824, -1.5526, -1.5425, 
    -1.0785, -1.7195, -3.2952, -2.4553, -2.39, -1.5981, -1.8299, 
    -1.8514, -2.0582, -2.2394, -1.5851, -1.8478, -0.13488, -0.80823, 
    -0.71257, -0.64596, 0.5024, 0.98108, 2.0211)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 7, 8, 9, 
    10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 
    25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 
    40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 
    55, 56, 57, 58), vals = c(-1.2527, -1.6417, -1.2375, -1.7768, 
    -1.9944, -0.90744, -0.48887, -0.5059, -0.86994, -1.0363, 
    -0.82948, -1.0376, -0.76698, -1.4402, -1.5172, -1.8798, -1.3748, 
    -1.2218, -1.2795, -1.1563, -0.95514, -1.2946, -1.2071, -1.2071, 
    -1.3576, -1.8372, -1.5284, -1.7639, -1.2731, -0.81087, -1.1205, 
    -1.6408, -1.0565, -1.5893, -1.3715, -1.8063, -0.99967, -0.88289, 
    -1.2689, -1.9939, -2.1569, -1.5939, -1.5194, -0.78723, -1.5329, 
    -0.99591, -1.3906, -1.1312, -0.60552, -1.1972, -1.0801, -0.74178, 
    -0.70749, -0.032406, 1.6001, 1.3215, 0.71199)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
    26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 
    41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 
    56, 57, 58), vals = c(-1.0143, -0.80716, -0.90052, -0.91978, 
    -0.86863, -1.251, -1.3839, -1.3124, -0.66518, -0.80787, -1.1763, 
    -1.0807, -1.6122, -1.2668, -1.843, -1.6732, -1.632, -1.7119, 
    -1.6041, -1.5334, -1.6946, -1.6099, -1.3759, -1.4808, -1.6325, 
    -1.6107, -1.6168, -1.4689, -0.9167, -1.1712, -0.86935, -1.3319, 
    -1.5854, -1.0442, -0.95923, -0.9685, -1.1301, -1.3559, -2.0001, 
    -1.904, -1.5139, -1.4099, -1.9853, -1.7578, -1.5256, -2.0745, 
    -1.4741, -1.6102, -1.6673, -0.44619, -1.3883, -0.9464, 0.039786, 
    1.1473, 1.1929, 1.8366)), .Names = c("args", "vals")), structure(list(
        args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 
        15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
        29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 
        43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
        57, 58), vals = c(-2.8022, -2.7567, -2.6208, -2.4485, 
        -2.6207, -1.8639, -1.5712, -1.1596, -0.60345, -1.0266, 
        -0.28794, -1.1413, -0.92926, -1.5798, -1.6448, -1.3155, 
        -1.3594, -1.9011, -2.2338, -2.2802, -1.9042, -2.4548, 
        -2.7236, -1.6292, -2.1842, -1.8546, -2.2061, -2.2971, 
        -2.1818, -2.1488, -1.8793, -1.6506, -1.5604, -1.6285, 
        -1.8928, -1.6833, -1.8787, -1.648, -1.8299, -1.8796, 
        -2.0378, -2.5248, -2.372, -2.2715, -1.4612, -1.3099, 
        -1.7588, -1.9286, -1.9729, -1.6712, -2.092, -1.7958, 
        -1.9246, -2.0138, -1.7633, 0.37726, 1.6916, 1.3501)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(0.27515, 0.51283, 0.71669, 
    0.95748, 1.3638, 1.7739, 1.8032, 1.6298, 1.4504, 1.2996, 
    1.5536, 0.91621, 0.64563, 0.30894, 0.52025, 0.46398, -0.49047, 
    -0.25551, -0.73395, -0.71207, -0.62867, -0.86447, -0.77196, 
    -0.83368, -1.1805, -1.3374, -1.6298, -1.3922, -1.6275, -1.6827, 
    -1.1139, -1.2841, -1.4273, -1.1431, -0.75992, -0.80388, -1.2353, 
    -0.5556, -0.67353, -1.3565, -1.4599, -0.95032, -0.8221, -1.2258, 
    -0.7137, -0.69885, -1.3797, -0.57731, -0.38457, -0.61111, 
    -0.46575, -0.47485, -0.68962, -0.71412, -1.2092, -1.2743, 
    -1.3927, -1.4753)), .Names = c("args", "vals")), structure(list(
        args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 
        15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
        29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 
        43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
        57, 58), vals = c(-4.1022, -4.2534, -4.4378, -3.7574, 
        -3.801, -3.4211, -3.2858, -3.2989, -3.6529, -3.3334, 
        -3.4396, -3.2918, -3.3722, -3.5124, -3.3288, -3.1227, 
        -1.7678, -0.81458, 1.8906, 1.1111, 1.5919, 1.5818, 3.2307, 
        3.4077, 3.7184, 3.8384, 4.4754, 4.072, 3.9207, 4.0182, 
        2.922, 2.8843, 2.8827, 2.8448, 2.8126, 3.005, 4.0054, 
        3.5281, 3.8668, 0.9327, 0.096867, -3.3952, -3.06, -2.6703, 
        -1.9956, -1.9027, -1.9665, -3.8593, -4.2911, -2.4844, 
        -3.669, -0.43768, -1.0939, 0.95939, 2.39, 4.2534, 3.6148, 
        4.383)), .Names = c("args", "vals")), structure(list(
        args = c(1, 2, 3, 4, 5, 7, 8, 9, 10, 12, 13, 14, 15, 
        16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 
        30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 
        44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 
        58), vals = c(-2.5505, -2.4491, -2.285, -2.234, -2.13, 
        -1.988, -2.3272, -2.3893, -2.6542, 0.22354, -2.4932, 
        -2.4512, -1.0397, -1.9016, -1.7318, -1.0406, 0.59166, 
        0.08764, 0.78481, 1.0425, 1.4651, 1.8966, 1.3582, 2.1972, 
        2.9122, 2.6157, 2.1388, 2.384, 1.4098, 1.9567, 2.7662, 
        1.62, 2.9011, 2.2204, 2.9271, 2.8923, 2.5272, 1.3125, 
        -0.47399, -3.3681, -3.1407, -3.2044, -2.1731, -1.8413, 
        -2.1645, -3.3795, -3.4742, -2.3603, -3.7444, 0.17153, 
        -1.3046, 0.15857, 1.9574, 3.0514, 2.5748, 3.3268)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 7, 8, 9, 
    10, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
    26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 
    41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 
    56, 57, 58), vals = c(-2.2682, -2.0378, -2.3661, -1.8691, 
    -2.3196, -1.8782, -1.9847, -1.7841, -1.5515, -1.6619, -1.7558, 
    -1.8905, -1.8175, -1.146, -1.1364, 0.38376, 1.8603, 1.4784, 
    1.7256, 1.726, 1.6531, 1.7097, 1.5349, 1.6342, 1.4803, 1.4754, 
    1.3678, 1.7578, 1.808, 1.0281, 0.95571, 1.4594, 1.8077, 1.5619, 
    1.795, 1.4462, 1.8131, -0.18738, -0.60884, -2.4798, -1.5005, 
    -1.2006, -0.66347, -1.2924, -1.2758, -1.3807, -0.58783, -0.8918, 
    -1.7464, 0.29046, -0.025449, 0.46437, 1.9269, 2.2104, 2.3196, 
    2.7216)), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 13, 14, 15, 16, 17, 18, 19, 20, 
    21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
    36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
    51, 52, 53, 54, 56, 58), vals = c(-2.3757, -3.7815, -4.4686, 
    -3.1403, -3.5073, -3.7768, -3.8978, -3.9283, -3.5931, -3.7889, 
    -3.9335, -3.8209, -1.5319, -3.2229, -2.7382, -1.3633, 1.1983, 
    0.64008, 1.0222, 1.6351, 1.8606, 2.2717, 2.818, 3.1313, 3.2944, 
    3.2181, 2.8944, 2.8381, 2.9004, 3.3313, 3.7637, 2.5325, 3.2123, 
    3.2608, 3.963, 4.0358, 3.3732, 2.1083, -1.3061, -4.0378, 
    -3.301, -2.8992, -2.1248, -1.7525, -1.489, -4.5086, -3.8503, 
    -2.6474, -4.6998, 0.97213, 0.9847, 1.1808, 4.9464, 4.4504
    )), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-2.9647, 
    -2.8465, -2.7535, -2.7667, -2.9503, -2.5141, -2.2861, -2.7593, 
    -2.7662, -2.3499, -2.901, -2.0403, -2.1136, -2.2808, -1.4499, 
    -2.1873, -1.7927, -1.1691, 0.50762, -0.3823, 0.35563, 0.63589, 
    1.5066, 1.8207, 1.6716, 2.2113, 2.3232, 2.1804, 2.219, 2.2771, 
    1.2564, 1.3094, 1.6742, 1.4324, 1.1455, 1.3402, 1.4883, 1.0765, 
    1.962, 0.037706, -1.1688, -2.2425, -1.7824, -1.3859, -0.98286, 
    -1.1925, -1.3082, -2.429, -2.731, -1.8424, -2.3956, -0.31538, 
    -0.60671, 0.087781, 1.4027, 2.4532, 2.4028, 3.1717)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(0.82586, 0.95486, 0.89852, 
    1.2833, 1.4719, 2.0835, 2.2499, 2.3295, 2.6478, 2.5256, 2.6215, 
    0.84617, 1.9111, 1.6534, 1.3125, 1.2033, 1.4624, 0.66444, 
    -0.3221, -0.075235, -0.17418, -0.66227, -0.63085, -1.0554, 
    -0.94173, -1.0251, -0.76692, -0.53302, -1.4666, -1.258, -1.1464, 
    -2.2161, -1.4588, -1.4825, -0.45397, -0.68988, -0.90199, 
    -1.0943, -1.2507, -1.252, -0.24918, -1.6052, -1.559, -1.8464, 
    -1.4468, -1.3952, -1.4436, -1.3475, -1.1845, -1.8209, -1.7579, 
    -1.4183, -1.6582, -1.836, -2.2532, -2.5001, -2.4932, -1.86
    )), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-1.2518, 
    -1.2025, -1.0684, -1.1692, -1.118, -0.80405, -0.82036, -0.92475, 
    -0.79807, -0.49089, -0.68753, -0.55966, -0.80062, -0.49696, 
    -0.75615, -0.91673, -0.82756, -0.59655, 0.6894, 0.49021, 
    0.4045, 0.92317, 0.51972, 0.66154, 0.64959, 0.45592, 0.59671, 
    0.61468, 0.77217, 1.0582, 0.4629, 0.70546, 0.61369, 0.8733, 
    0.52559, 0.8406, 0.80432, 0.4842, 0.27694, -0.018798, -0.07291, 
    -0.38115, -0.75655, -0.97372, -0.071398, -0.7185, -1.241, 
    -0.8384, -0.74566, -0.72121, -0.75247, -0.10146, -0.3927, 
    -0.070677, 0.79456, 1.2025, 1.68, 1.2607)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(-2.4009, -2.6158, -1.9066, 
    -1.8948, -1.4874, -1.5892, -1.3921, -1.3654, -1.4148, -1.6128, 
    -1.7279, -1.5062, -1.0767, -1.8399, -1.7329, -1.2085, -0.85771, 
    -0.46659, 0.26335, 0.096116, 0.22733, 0.32166, 0.79156, 1.5095, 
    1.3546, 1.7305, 1.7231, 1.5473, 1.5143, 1.3566, -0.032963, 
    0.50067, 0.98325, 0.60991, 1.1406, 1.1152, 1.51, 1.4206, 
    2.1084, 0.79058, -0.94401, -1.2661, -1.4958, -1.8016, -1.1233, 
    -1.3229, -1.7649, -0.80416, -1.343, -0.46563, -0.77728, 0.09011, 
    0.011545, -0.042161, 0.79544, 1.9066, 1.7829, 1.9625)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(-2.236, -2.1199, -1.79, -1.17, 
    -1.3822, -1.3758, -1.2821, -1.2688, -0.78279, -0.64987, -0.83769, 
    -0.82933, -1.258, -0.72608, -1.3391, -1.9359, -1.3032, -1.9297, 
    -2.0197, -1.8419, -1.592, -1.6896, -1.7644, -2.2208, -2.1856, 
    -2.2103, -1.9618, -1.7803, -2.1709, -1.6451, 0.16225, 0.17169, 
    0.027947, -0.31748, -0.091141, 0.17765, 0.45627, 0.87568, 
    0.66053, -0.21036, 0.14771, -1.4328, -1.7523, -0.97116, -0.74562, 
    -0.52471, -0.29803, -0.91412, -1.1102, -1.0996, -1.6844, 
    -1.3647, -1.6583, -1.4025, -1.2641, -1.538, -1.8828, 0.50754
    )), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-1.3828, 
    -1.3701, -1.8362, -1.9782, -2.2321, -2.6164, -1.974, -1.7956, 
    -1.7807, -1.778, -1.9007, -1.6936, -1.7139, -1.7765, -1.4176, 
    -1.591, -1.6128, -1.5797, -1.5089, -1.5447, -1.3361, -1.4867, 
    -1.3247, -1.1999, -1.2894, -1.2243, -0.93212, -0.87465, -1.1033, 
    -0.95942, -0.73921, -0.70976, -1.0494, -0.58553, -0.8757, 
    -0.96322, -0.75712, -0.94316, -0.77872, -1.1979, -1.5335, 
    -1.3287, -1.2863, -1.3147, -1.3252, -1.4355, -1.4558, -1.1293, 
    -1.2362, -0.68634, -0.27041, -0.86892, -0.096449, -0.26915, 
    0.69522, 1.6068, 1.4974, 2.0524)), .Names = c("args", "vals"
    )), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
    11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
    26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 
    41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 
    56, 57, 58), vals = c(-3.1223, -3.2783, -2.887, -2.6972, 
    -2.8282, -2.5501, -2.6004, -2.2922, -2.465, -2.4474, -2.4604, 
    -2.059, -1.9968, -2.2331, -2.1022, -2.1254, -1.3521, -0.98427, 
    0.48172, -0.3805, 0.092261, 0.46139, 1.6261, 1.9909, 1.7876, 
    2.2637, 2.4978, 2.4403, 2.3742, 2.3813, 0.0087803, 0.38007, 
    0.76438, 0.11169, 1.1245, 0.088837, 1.3653, 1.1192, 2.0883, 
    -0.31288, -0.50561, -1.682, -1.3057, -0.74766, -0.66427, 
    -1.5915, -1.9436, -1.9885, -2.3045, -2.156, -2.3584, 0.10199, 
    -0.98724, 0.11465, 0.92157, 2.6453, 2.3028, 3.0481)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(0.56036, 0.47119, 0.68405, 
    1.1679, 1.6553, 1.8647, 1.876, 1.9879, 1.5718, 1.4256, 1.591, 
    0.69104, 0.65341, 0.88616, 0.51554, 0.65228, 0.38495, -0.10926, 
    -0.025263, -0.41453, -0.70473, -0.46509, -0.41516, -0.68369, 
    -0.71685, -0.91793, -1.4537, -1.4579, -1.2596, -1.3936, -0.881, 
    -1.4757, -1.1735, -1.198, -0.61134, -0.62953, -0.54527, -0.75178, 
    -1.003, -0.47245, -0.78081, -0.68434, -0.52801, -0.71609, 
    -0.69067, -0.92498, -0.7524, -0.90356, -0.1212, -0.47989, 
    -0.91712, -1.06, -1.3278, -1.2272, -1.3411, -1.5365, -1.4069, 
    -2.0408)), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-0.68659, 
    -0.90586, -0.88038, -0.91058, -0.9549, -1.5964, -1.4389, 
    -1.2262, -1.2513, -1.2167, -0.84325, -1.8643, -1.0332, -1.5157, 
    -1.3701, -1.2103, -0.70187, -1.2572, -2.2039, -1.8386, -1.6683, 
    -1.9815, -1.6022, -1.7611, -2.0166, -2.2263, -1.7727, -2.033, 
    -1.9066, -1.8568, -2.3642, -2.1568, -2.0101, -2.4108, -2.131, 
    -2.208, -2.3814, -2.4148, -2.172, -2.2718, -2.7133, -2.4115, 
    -2.5691, -2.2144, -2.2019, -2.0138, -3.1516, -2.2947, -2.086, 
    -1.8884, -1.8032, -2.1694, -2.0265, -2.5761, -1.7054, -0.27012, 
    -0.11167, 1.3106)), .Names = c("args", "vals")), structure(list(
        args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 
        15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
        29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 
        43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
        57, 58), vals = c(0.40894, 0.44998, 0.88768, 1.1766, 
        1.3692, 1.8087, 2.0432, 1.856, 1.5051, 1.3141, 1.1953, 
        1.1905, 1.0657, 1.2501, 1.2471, 1.0179, 0.80295, 0.73537, 
        0.30854, 0.40773, 0.16358, 0.2516, -0.20718, -0.29804, 
        -0.40783, -0.89264, -1.0557, -0.86111, -0.74738, -0.78292, 
        -1.12, -1.8114, -1.8994, -0.90914, -1.2612, -1.3961, 
        -1.1666, -1.1697, -0.69896, -0.92088, -0.37355, -0.54371, 
        -0.66163, -1.1993, -0.85896, -0.66826, -1.3009, -0.56389, 
        -0.48078, -0.88382, -0.48478, -0.98807, -0.71154, -0.96145, 
        -1.3076, -1.2825, -1.5546, -1.5198)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(-3.5477, -3.6674, -3.5145, 
    -3.7037, -3.8575, -3.0589, -3.1529, -2.9369, -4.0039, -3.0987, 
    -2.6082, -2.5499, -3.3606, -3.7775, -3.5615, -2.9392, -2.2508, 
    -2.0557, -0.14162, -1.0419, -0.47629, -0.36151, 0.75091, 
    1.363, 1.4297, 2.0365, 4.0194, 3.7775, 2.7367, 3.48, 1.9695, 
    2.1749, 2.8554, 1.9881, 2.7153, 2.2726, 2.3325, 1.7846, 2.4141, 
    1.4338, -2.0406, -3.3874, -3.4597, -2.6996, 0.038456, 1.2738, 
    1.1096, -2.8358, -3.4847, -2.2461, -2.6384, -1.3893, -1.3042, 
    -0.43789, 1.0225, 2.2846, 2.4933, 4.0445)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(-4.2716, -4.3934, -3.7853, 
    -4.0175, -3.5392, -3.3898, -3.3433, -3.5461, -3.6025, -3.4312, 
    -3.5075, -3.2676, -2.7472, -3.0146, -2.6276, -3.2024, -1.5914, 
    -0.44301, 1.8315, 1.2441, 1.835, 2.3267, 2.6673, 2.8035, 
    3.2297, 3.2743, 3.4706, 3.399, 3.215, 3.7177, 2.0619, 2.2402, 
    2.7754, 1.96, 2.8816, 2.427, 4.0713, 3.1269, 3.6022, -0.40357, 
    -1.6734, -4.1315, -4.0622, -3.9598, -3.2295, -3.4376, -3.1007, 
    -4.2366, -4.4452, -2.7374, -4.0234, 0.16725, -0.5718, 0.84041, 
    2.7774, 4.1935, 3.986, 4.8334)), .Names = c("args", "vals"
    )), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
    11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
    26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 
    41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 
    56, 57, 58), vals = c(-1.053, -0.85027, -0.81998, -0.53162, 
    -0.30978, -0.22342, -0.80429, -0.94834, -1.0864, -1.3897, 
    -1.3734, -1.2287, -1.5425, -1.2669, -1.1059, -1.2322, -1.123, 
    -0.95899, 0.40183, -0.11467, 0.37883, 0.83388, 0.74308, 0.68975, 
    1.137, 1.1322, 1.3577, 1.043, 1.0162, 1.3241, 0.279, 0.40651, 
    0.86622, 0.18417, 0.73219, 0.6233, 1.5088, 1.2358, 1.4264, 
    -0.82565, -0.96114, -1.5056, -1.7218, -2.0087, -1.8178, -1.2654, 
    -1.5196, -1.717, -1.8463, -1.7929, -1.0914, -0.48956, -0.86869, 
    -0.27297, 0.91833, 1.3114, 1.5189, 1.8675)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(-3.2335, -3.2497, -3.3629, 
    -3.4514, -2.8834, -3.1661, -3.337, -3.5095, -3.5409, -3.3908, 
    -3.5133, -4.0007, -2.5691, -3.1956, -2.1316, -2.8473, -2.6918, 
    -2.7066, -3.1876, -3.0292, -2.7803, -3.1458, -2.5631, -2.3321, 
    -2.1857, -2.2455, -2.7311, -2.6206, -2.3136, -2.5741, -3.3263, 
    -2.8533, -3.2045, -3.0007, -2.9926, -2.8712, -2.6691, -1.793, 
    -1.6475, -1.6395, -1.9024, -1.408, -1.4361, -1.0962, -1.1038, 
    -0.97, -1.4769, -0.43247, -0.30805, -0.49236, -0.53756, -0.62158, 
    -0.84938, -0.84645, -0.58705, 0.65523, 1.1847, 0.19001)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(-2.0392, -2.1691, -2.0578, 
    -2.075, -2.4869, -2.2936, -2.2224, -1.9854, -1.7529, -1.6047, 
    -1.1403, -1.4723, -2.0383, -1.5284, -2.3009, -2.3348, -2.4768, 
    -2.7808, -2.5272, -2.2327, -2.3782, -2.3185, -2.6027, -2.1189, 
    -2.557, -3.0252, -2.7805, -2.8244, -2.5399, -2.5585, -1.6589, 
    -2.0239, -2.0476, -1.8477, -2.2122, -1.5746, -1.6198, -1.5688, 
    -1.7122, -2.5672, -2.1794, -3.0177, -2.6567, -2.442, -2.5096, 
    -1.21, -0.94896, -1.5294, -1.1271, -1.3341, -1.6897, -1.5791, 
    -1.5952, -0.04356, 2.5817, 2.5157, 2.2601, 1.6914)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(0.025197, 0.11202, 0.47555, 
    0.44883, 0.44042, 1.478, 1.3552, 1.3188, 1.7679, 2.0945, 
    1.2539, 2.1788, 2.5413, 2.4165, 0.88462, 1.5853, 0.57102, 
    0.52045, -0.83179, -0.33901, -0.5707, -0.17024, -0.42449, 
    -1.6711, -1.3631, -1.4299, -1.7042, -1.58, -1.6653, -2.0181, 
    -0.61634, -0.89007, -1.544, -0.42811, -0.9804, -0.78747, 
    -2.0881, -0.81021, -0.89544, -0.69954, -1.283, -1.739, -1.7536, 
    -1.6337, -0.70943, -1.2875, -1.0047, -0.77491, -0.91674, 
    -0.92904, -1.1199, -0.65612, -0.97015, -0.8954, -1.7192, 
    -2.0214, -2.0713, -1.228)), .Names = c("args", "vals")), 
    structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
    12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 
    27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 
    42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
    57, 58), vals = c(-0.79923, -0.74363, -0.81837, -0.4437, 
    -0.25429, -0.5812, -0.60233, -0.5342, -0.42219, -0.85315, 
    -0.71974, -0.92185, -1.0703, -1.2446, -0.87028, -0.37878, 
    -0.99054, -0.32998, 0.36489, -0.23087, 0.17922, 0.3855, 0.55692, 
    0.52552, 0.63893, 0.66148, 0.65238, 0.52749, 0.50931, 0.31145, 
    0.1436, -0.17414, 0.10909, -0.25276, -0.13092, -0.038859, 
    0.040268, -0.069377, 0.155, 0.0088495, -0.68163, -1.1391, 
    -0.57225, -0.84645, 0.18858, 0.1223, 0.0091717, -0.99218, 
    -1.0068, -1.0931, -1.3051, -0.10974, -0.66219, -0.34518, 
    0.56173, 0.97741, 1.1391, 1.2811)), .Names = c("args", "vals"
    )), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
    11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
    26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 
    41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 
    56, 57, 58), vals = c(1.0239, 1.2401, 1.453, 1.8113, 2.3137, 
    3.313, 3.1167, 3.1997, 2.6293, 2.3013, 2.4541, 2.3017, 2.6378, 
    2.2296, 1.601, 1.31, 1.6575, 0.71794, -0.55239, -0.34436, 
    -0.47208, -0.59243, -0.97043, -1.8587, -1.4149, -1.7983, 
    -2.316, -2.2465, -2.2343, -2.3988, -2.7557, -3.0756, -3.1678, 
    -2.1588, -3.1167, -2.841, -3.7943, -2.6958, -2.2207, -1.2781, 
    -0.51212, -0.72825, -0.76581, -1.0616, -1.4957, -0.35509, 
    -0.82237, -0.34428, -0.043276, -0.56915, -0.38651, -0.21491, 
    -0.15788, -0.4082, -1.497, -2.2965, -2.4047, -1.9422)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(0.98997, 1.5709, 1.6223, 2.5249, 
    2.6054, 3.6676, 3.0687, 2.6426, 0.14083, -0.075099, 0.68627, 
    0.045393, -0.83418, -0.49673, -0.33204, -0.83616, -1.3025, 
    -1.671, -1.5832, -1.3332, -1.5965, -1.2317, -1.7676, -1.8897, 
    -1.9718, -2.3162, -2.331, -2.3796, -2.1399, -2.1284, -1.3623, 
    -1.8621, -2.2319, -1.5028, -2.0204, -1.5563, -1.5661, -1.6843, 
    -1.1408, -1.9366, -0.93642, -2.1324, -2.0376, -1.4161, -1.9304, 
    -2.0632, -2.1462, -2.3336, -2.2837, -1.5156, -2.3568, -1.8262, 
    -1.9305, -1.827, -2.3452, -2.5024, -2.3992, -1.7664)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(0.49392, 0.50748, 1.0213, 1.3177, 
    1.4437, 1.8346, 1.9425, 1.6761, 1.4438, 1.1832, 1.481, 1.0293, 
    0.92333, 1.3663, 0.89126, 0.79769, 0.98061, 0.030007, -0.053868, 
    0.10333, -0.15901, -0.21221, -0.67295, -0.61341, -0.63164, 
    -0.71547, -1.0346, -0.94349, -0.78858, -1.0334, -1.4511, 
    -1.8427, -1.7253, -1.39, -1.4336, -1.3142, -1.2767, -1.3432, 
    -0.90628, -0.78193, -0.67202, -0.49273, -0.87698, -0.55959, 
    -0.82487, -0.61497, -0.66968, -0.53121, -0.1648, -0.36448, 
    -0.095286, -0.6651, -0.39045, -0.77562, -1.3247, -1.1639, 
    -1.3318, -1.2161)), .Names = c("args", "vals")), structure(list(
        args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 
        15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
        29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 
        43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
        57, 58), vals = c(-0.47826, -0.53248, -0.64984, -1.9241, 
        -0.71385, -0.89936, -0.97666, -1.1178, -1.6219, -1.5896, 
        -1.3785, -0.55225, -1.4169, -1.4845, -1.0522, -0.63978, 
        -0.52304, 0.010697, -0.30595, -0.39137, -0.058812, -0.19731, 
        0.087949, 0.27921, 0.41393, 0.39551, 0.69758, 0.76925, 
        0.26941, 0.66833, 0.71016, 0.26457, 0.41245, -0.20376, 
        0.44032, -0.084359, 0.47477, 0.10467, -0.34477, -1.1296, 
        -0.77298, -1.0072, -1.1183, -1.0175, -1.1824, -0.58034, 
        -1.4363, -1.0394, -1.0452, -1.417, -1.2137, -1.0072, 
        -0.89876, -0.53502, 0.26613, 0.93286, 0.68914, 1.4041
        )), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-2.1578, 
    -2.4369, -2.4397, -2.882, -3.02, -2.5325, -2.3687, -2.1503, 
    -2.3904, -2.0253, -2.0149, -2.4346, -1.9018, -2.6028, -2.4781, 
    -2.6484, -1.7231, -1.5891, -1.6629, -1.747, -1.5241, -1.6891, 
    -0.65261, -0.18204, 0.34165, 0.70719, 2.2579, 2.1696, 1.0849, 
    2.0468, 1.2916, 1.1105, 0.9564, 1.6266, 1.2679, 1.3741, 0.40911, 
    0.067718, 0.092934, -1.1088, -0.60987, -2.6767, -1.9503, 
    -2.8238, -1.7587, -1.9005, -1.7294, -2.6747, -2.5421, -2.111, 
    -2.8308, -1.645, 0.042504, -0.18821, 0.79597, 2.4264, 1.4003, 
    3.0803)), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-0.13425, 
    -0.23329, -0.20175, -0.62691, -0.80816, -1.8992, -2.3735, 
    -2.5239, -2.4828, -2.1844, -2.2455, -1.4901, -2.1304, -2.0703, 
    -1.1428, -1.0724, -1.1313, -0.21036, -0.31316, -0.099941, 
    -0.14913, -0.21452, -0.012223, -0.089673, -0.27305, -0.3253, 
    -0.24045, -0.32318, -0.50836, -0.51695, -0.72729, -0.40319, 
    -0.72877, -0.79741, -1.0287, -0.79627, -1.1574, -1.4649, 
    -1.1678, -0.90867, -0.73269, -0.017765, -0.35069, -0.63305, 
    -0.70216, -0.77182, -1.0831, -0.97779, -0.98144, -0.70151, 
    -0.92983, -0.62219, -0.57214, -1.0818, -0.9223, 0.16176, 
    0.56869, -0.52284)), .Names = c("args", "vals")), structure(list(
        args = c(1, 2, 3, 4, 5, 6, 8, 9, 10, 11, 12, 13, 14, 
        15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
        29, 30, 31, 32, 33, 34, 35, 36, 38, 39, 40, 41, 42, 43, 
        44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 56, 58), 
        vals = c(-3.2072, -3.1093, -3.3515, -3.1328, -2.8916, 
        -2.911, -2.5433, -2.2632, -2.0722, -1.616, -1.9665, -1.9428, 
        -1.9284, -2.1191, -1.7945, -1.758, -1.2232, -0.5727, 
        -0.94536, -0.89382, -0.7164, 1.1023, 1.4137, 1.9329, 
        2.4356, 3.4934, 3.1328, 2.5395, 3.1733, 1.8839, 1.959, 
        1.8446, 1.6232, 1.9893, 1.7864, 1.7587, 1.7208, 0.69304, 
        -0.43172, -2.3092, -2.5603, -1.8318, -0.80958, -0.70384, 
        0.0025463, -1.6932, -1.363, -1.6496, -1.6445, -1.8138, 
        -1.7163, -2.1999, 1.2047, 1.1636)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(-2.7902, -2.5524, -2.0425, 
    -2.1045, -1.5762, -1.7247, -1.4946, -1.8115, -2.1901, -1.9568, 
    -2.0513, 0.15937, -0.96575, -1.5442, -0.93174, -1.4219, -1.08, 
    -0.64003, 1.2032, 0.010765, 0.76469, 1.0427, 1.9819, 2.0584, 
    2.0905, 1.8881, 1.2435, 0.84331, 1.4012, 1.0293, -0.28936, 
    -0.54818, 0.48937, -0.18132, 0.4834, 0.28233, 0.29678, 0.57683, 
    0.35394, -0.26434, -1.1934, -1.6172, -1.4672, -1.3209, -1.2147, 
    -0.71576, -0.79475, -1.7755, -1.3593, -0.68891, -0.86412, 
    -0.20407, -0.54233, -0.24714, 2.0776, 2.1261, 1.7831, 1.614
    )), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-1.5099, 
    -1.5155, -1.87, -1.7792, -1.9429, -2.012, -1.197, -0.90152, 
    -1.0713, -1.2163, -1.1657, -0.46713, -1.6654, -1.9698, -1.3536, 
    -1.0744, -0.98049, -0.76706, -0.15464, -0.36091, 0.36327, 
    0.27185, 0.53632, 0.97095, 1.0734, 1.1096, 1.7406, 1.6457, 
    1.0535, 1.2861, 0.88486, 1.2849, 1.6269, 0.94397, 1.9107, 
    1.6124, 2.1197, 2.2532, 1.8136, 0.22014, -0.92087, -1.9369, 
    -1.937, -2.1627, -1.5439, -1.2826, -1.8036, -2.2532, -2.3862, 
    -1.984, -2.3265, -0.023233, -0.87743, -0.32979, 1.6081, 1.7863, 
    3.4716, 1.7669)), .Names = c("args", "vals")), structure(list(
        args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 
        15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
        29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 
        43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
        57), vals = c(-1.6706, -1.8633, -1.7941, -1.9005, -2.0288, 
        -2.6508, -1.8789, -1.3332, -2.0486, -2.0754, -1.8191, 
        -1.0318, -1.8848, -2.0822, -2.1328, -1.3562, -1.4967, 
        -1.4228, -0.43553, -0.68684, -0.17186, -0.017898, 0.24051, 
        0.55692, 0.62636, 0.85765, 1.1391, 1.2505, 0.83445, 1.1686, 
        0.54151, 1.0714, 0.76261, 0.57714, 0.89749, 0.76769, 
        0.70533, 1.1794, 0.95823, 0.091374, -0.40309, -1.7602, 
        -1.615, -1.5642, -1.2724, -1.3008, -1.258, -1.2735, -1.4076, 
        -0.86137, -1.562, 0.56904, 0.20466, 0.40973, 1.8705, 
        1.4415, 2.4995)), .Names = c("args", "vals")), structure(list(
        args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 
        15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
        29, 30, 31, 32, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 
        44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57
        ), vals = c(-0.30009, -0.0028192, 0.01685, 1.7111, 2.5692, 
        3.5631, 2.6037, 3.3339, 2.0959, 1.1893, 1.2186, 1.5457, 
        1.5274, 1.5534, 1.6092, 0.76756, 1.1001, 0.79854, 0.17324, 
        0.45146, -0.18215, -0.16527, -0.69817, -0.80132, -0.26416, 
        -0.73839, -0.69653, -0.76767, -0.83233, -1.1554, -0.29379, 
        -0.74948, -0.53187, -0.6071, -0.17858, -0.39755, -0.81972, 
        -0.069527, -0.4296, -0.25986, -0.86598, -0.81184, -0.7176, 
        -0.70874, -1.824, 0.44805, -1.1588, -1.0474, -0.7128, 
        -1.6046, -1.6127, -1.2834, -1.4646, -0.60561, -1.8979, 
        -0.94163)), .Names = c("args", "vals")), structure(list(
        args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 
        15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
        29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 
        43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
        57, 58), vals = c(-1.813, -1.5468, -1.8535, -1.6417, 
        -1.518, -1.5876, -1.1776, -0.92776, -0.55519, -0.46922, 
        -0.49639, -0.96518, -0.83886, -0.99835, -0.65509, -0.81314, 
        -0.50154, -0.48024, 0.085173, -0.14656, 0.40238, 0.30629, 
        0.56055, 0.69524, 0.64815, 0.81082, 1.3061, 1.2525, 0.773, 
        1.0251, 0.58044, 0.98263, 1.0582, 0.54784, 1.2109, 1.134, 
        1.2546, 1.6417, 1.1376, 0.083988, -0.067499, -0.78773, 
        -1.1319, -1.5017, -0.93007, -0.4107, -0.56333, -1.0376, 
        -1.2627, -1.1342, -1.3224, 0.068414, -0.44102, -0.2047, 
        1.238, 0.97678, 1.572, 0.8015)), .Names = c("args", "vals"
    )), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
    11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
    26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 
    41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 
    56, 57, 58), vals = c(-2.0649, -2.267, -2.3289, -2.736, -2.6242, 
    -2.3911, -2.3438, -2.4359, -1.7199, -1.916, -1.907, -1.8135, 
    -1.4666, -1.3587, -1.483, -1.258, -1.2419, -0.76389, 0.27932, 
    -0.38177, 0.22691, 0.6127, 0.78523, 0.73521, 1.189, 1.2331, 
    1.2198, 1.1854, 0.82822, 1.0845, 0.64536, 0.75396, 1.0945, 
    0.7805, 1.465, 1.3482, 1.0696, 1.6814, 1.6881, -0.13959, 
    0.1298, -1.7667, -1.4062, -2.0362, -1.5186, -1.2403, -0.98331, 
    -2.2802, -2.0245, -1.8417, -2.2423, -0.10815, -0.94332, -0.43899, 
    1.1745, 1.281, 1.9511, 1.3293)), .Names = c("args", "vals"
    )), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
    11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
    26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 
    41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 
    56, 57, 58), vals = c(0.38609, 0.49621, 0.27106, 0.52798, 
    0.64974, 0.39951, 0.35059, 0.092336, 0.34667, 0.086345, -0.058399, 
    0.1397, 0.0046862, 0.21375, 0.43467, 0.038462, 0.17312, -0.70196, 
    -1.2219, -1.164, -0.96399, -1.439, -1.1791, -0.80696, -1.2866, 
    -1.275, -0.85485, -0.83844, -1.3278, -1.3487, -0.49621, -1.0378, 
    -1.5265, -1.2573, -1.0738, -1.2892, -1.3397, -1.0056, -0.65868, 
    -1.7747, -1.6357, -1.1527, -1.4047, -1.3668, -2.0062, -1.3933, 
    -2.0862, -1.0876, -0.85722, -1.3112, -1.525, -1.3382, -1.072, 
    -1.3831, -1.939, -0.59218, -1.0532, -0.16516)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(-2.5838, -2.764, -2.3922, -2.7309, 
    -2.6163, -2.8835, -2.3395, -2.7239, -2.252, -2.6999, -1.9798, 
    -1.8271, -3.0194, -2.4282, -2.6319, -2.0558, -2.5744, -2.9578, 
    -2.2049, -2.2496, -2.3323, -2.1977, -1.8155, -1.5337, -1.1055, 
    -1.8779, -1.9381, -1.9513, -1.5836, -1.4386, -0.64091, -0.74621, 
    -1.0965, -0.92915, -1.4551, -0.81951, -1.4372, -0.64898, 
    -0.55435, -1.5133, -1.7801, -2.8072, -2.1376, -2.228, -2.5776, 
    -2.0375, -1.5044, -2.3069, -2.1376, -1.6664, -2.4527, -0.33095, 
    -0.7711, 1.1506, 2.9691, 3.5009, 2.8835, 0.81016)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(-0.6002, -0.85355, -0.59307, 
    -0.96863, -1.2549, -1.2476, -1.2819, -1.2215, -1.1295, -1.1324, 
    -1.0564, -0.96113, -1.1498, -0.59721, -0.97901, -1.0689, 
    -1.125, -1.1842, -0.71227, -1.0388, -0.93141, -0.88634, -0.82168, 
    -0.77656, -0.82573, -0.60789, -0.69569, -0.74296, -0.32223, 
    -0.78054, -0.85635, -0.85452, -1.0228, -0.78708, -0.99687, 
    -0.89283, -0.79915, -0.87398, -0.83541, -1.1011, -1.2227, 
    -1.2293, -1.0708, -0.89701, -0.46645, -1.2829, -0.73478, 
    -1.146, -0.67587, -0.60377, -0.57572, -0.98262, -0.71057, 
    -0.73836, -1.0249, -0.68233, -0.14793, 0.064206)), .Names = c("args", 
    "vals")), structure(list(args = c(1, 2, 3, 4, 5, 6, 7, 8, 
    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 
    24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 
    54, 55, 56, 57, 58), vals = c(-0.60649, -0.48247, -1.2019, 
    -1.734, -0.3734, -0.8626, -0.79553, -0.93697, -1.5921, -1.1111, 
    -1.5206, -1.6674, -1.8888, -2.0566, -2.729, -1.5131, -1.7839, 
    -1.8843, -1.6295, -1.6142, -1.3707, -1.6143, -1.2832, -1.2093, 
    -1.8257, -1.4968, -1.3344, -1.173, -1.6312, -1.1131, -0.62312, 
    -0.70205, -1.0231, -0.79068, -0.79858, -0.71482, -0.68275, 
    -0.67075, -0.60547, -1.2601, -0.80877, -1.8324, -1.4516, 
    -1.4864, -1.7459, -1.6272, -1.5206, -1.6363, -1.5739, -1.4586, 
    -1.6633, -1.1393, -0.5076, -0.30912, 1.3953, 1.8888, 1.7916, 
    1.9369)), .Names = c("args", "vals")), structure(list(args = c(1, 
    2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
    34, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 
    50, 51, 52, 53, 54, 55, 56, 57, 58), vals = c(-2.6442, -2.7789, 
    -2.5737, -2.8648, -2.2742, -2.5058, -2.5716, -2.4819, -2.0632, 
    -2.2503, -2.6557, -2.0771, -2.2775, -2.1053, -2.61, -2.7219, 
    -2.2947, -2.589, -2.1912, -2.3053, -1.7013, -1.649, -1.5332, 
    -1.1913, -0.85137, -0.45222, 0.75715, 0.51396, -0.36522, 
    0.52134, 0.36923, -0.37695, 0.26288, -0.17058, 0.34689, 0.93715, 
    0.88018, 1.0394, -2.4244, -1.907, -3.603, -4.1606, -2.887, 
    -3.1615, -3.0522, -3.4183, -3.7764, -3.535, -2.9324, -3.3939, 
    -2.4336, -1.7179, -1.4915, 0.2099, 1.2184, 2.5413, 3.603)), .Names = c("args", 
    "vals"))), labels = list(3, 3, 1, 1, 3, 1, 1, 1, 3, 3, 3, 
    3, 3, 2, 3, 3, 3, 3, 3, 1, 3, 1, 1, 3, 1, 3, 1, 3, 1, 3, 
    3, 2, 1, 3, 3, 3, 3, 1, 2, 2, 2, 2, 2, 1, 2, 2, 3, 3, 2, 
    1, 3, 1, 2, 2, 2, 3, 3, 1, 2, 1, 1, 1, 2, 2, 3, 2, 2, 2, 
    2, 1, 2, 2, 3, 3, 3, 3, 2)))
)